@@ -6,11 +6,10 @@ Authors: Zack Cerza <zcerza@redhat.com>, Ed Rousseau <rousseau@redhat.com>, Davi
 """
 
 __author__ = """Zack Cerza <zcerza@redhat.com>,
-Ed Rousseau <rousseau@redhat.com>, 
+Ed Rousseau <rousseau@redhat.com>,
 David Malcolm <dmalcolm@redhat.com>"""
-__version__ = "0.5.1"
+__version__ = "0.6.1"
 __copyright__ = "Copyright © 2005 Red Hat, Inc."
 __license__ = "GPL"
 
-__all__ = ("config", "predicate", "procedural", "tc", "tree", "utils")
-
+__all__ = ("config", "predicate", "procedural", "tc", "tree", "utils", "errors")
